package edu.sjsu.rhinofaces;

import java.io.IOException;
import java.util.Locale;
import java.util.logging.Logger;

import javax.faces.FacesException;
import javax.faces.application.ViewHandler;
import javax.faces.component.UIViewRoot;
import javax.faces.context.FacesContext;

/**
 
 @author Tom Austin
 */
public class RhinoViewHandler extends ViewHandler
{
   private static Logger logger = Logger.global;
   
   private ViewHandler delegate;
   
   /**
      @param viewHandler
    */
   public RhinoViewHandler(ViewHandler delegate)
   {
      this.delegate = delegate;
   }
   
   /**
    @return Returns the delegate.
    */
   public ViewHandler getDelegate()
   {
      return this.delegate;
   }

   /**
    @param delegate The delegate to set.
    */
   public void setDelegate(ViewHandler delegate)
   {
      this.delegate = delegate;
   }

   /**
   @see javax.faces.application.ViewHandler#renderView(javax.faces.context.FacesContext, javax.faces.component.UIViewRoot)
   */
   @Override
   public void renderView(FacesContext context, UIViewRoot viewRoot)
         throws IOException, FacesException
   {
      logger.info("renderView: " + viewRoot);
      delegate.renderView(context, viewRoot);
   }
   
   /**
      @see javax.faces.application.ViewHandler#getActionURL(javax.faces.context.FacesContext, java.lang.String)
   */
   @Override
   public String getActionURL(FacesContext context, String viewID)
   {
      logger.info("Getting url for " + viewID);
      String url = delegate.getActionURL(context, viewID);
      logger.info(url);
      return url;
   }

   /**
    @see javax.faces.application.ViewHandler#calculateLocale(javax.faces.context.FacesContext)
    */
   @Override
   public Locale calculateLocale(FacesContext arg0)
   {
      logger.info("calculateLocale");
      return delegate.calculateLocale(arg0);
   }

   /**
    @see javax.faces.application.ViewHandler#calculateRenderKitId(javax.faces.context.FacesContext)
    */
   @Override
   public String calculateRenderKitId(FacesContext arg0)
   {
      logger.info("calculateRenderKitId");
      return delegate.calculateRenderKitId(arg0);
   }

   /**
    @see javax.faces.application.ViewHandler#createView(javax.faces.context.FacesContext, java.lang.String)
    */
   @Override
   public UIViewRoot createView(FacesContext arg0, String arg1)
   {
      logger.info("createView: " + arg1);
      return delegate.createView(arg0, arg1);
   }

   /**
    @see javax.faces.application.ViewHandler#getResourceURL(javax.faces.context.FacesContext, java.lang.String)
    */
   @Override
   public String getResourceURL(FacesContext arg0, String arg1)
   {
      logger.info("getResourceURL");
      return delegate.getResourceURL(arg0, arg1);
   }

   /**
    @see javax.faces.application.ViewHandler#restoreView(javax.faces.context.FacesContext, java.lang.String)
    */
   @Override
   public UIViewRoot restoreView(FacesContext arg0, String arg1)
   {
      logger.info("restoreView");
      return delegate.restoreView(arg0, arg1);
   }

   /**
    @see javax.faces.application.ViewHandler#writeState(javax.faces.context.FacesContext)
    */
   @Override
   public void writeState(FacesContext arg0) throws IOException
   {
      logger.info("writeState");
      delegate.writeState(arg0);
   }
}
